==> hslua-cli-1.4.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/hslua-cli.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-cli
version:              1.4.2
visibility:           public
id:                   hslua-cli-1.4.2-62ckiX4WYquE4dEgS2Wqd7
key:                  hslua-cli-1.4.2-62ckiX4WYquE4dEgS2Wqd7
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Command-line interface for Lua
description:
    Provides an embeddable command-line interface for Lua.
    The interface is compatible with the standard Lua
    interpreter, i.e., the `lua` executable provided in a
    default Lua installation.

category:             Foreign
abi:                  d5c227544145558bb7e2a1b3f626b08f
exposed:              True
exposed-modules:      HsLua.CLI
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hslua-cli
hs-libraries:         HShslua-cli-1.4.2-62ckiX4WYquE4dEgS2Wqd7
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-38rmpo0BEKVLF3MmG72ryb
    hslua-marshalling-2.3.1-D72L6yeyMCIIEMpyzA6Yjm
    hslua-repl-0.1.2-8vAtVegWA974s5fn0Mur94
    lua-2.3.3-5zaR1oaLxjWFp9Bpv6YUxF text-2.0.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/hslua-cli/html/hslua-cli.haddock
haddock-html:         /usr/share/doc/hslua-cli/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hslua-cli-1.4.2-5-x86_64.pkg.tar.zst: usr/share/haskell/register/hslua-cli.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-cli
version:              1.4.2
visibility:           public
id:                   hslua-cli-1.4.2-2DWYwhXGNSHoe6K9HpV3l
key:                  hslua-cli-1.4.2-2DWYwhXGNSHoe6K9HpV3l
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Command-line interface for Lua
description:
    Provides an embeddable command-line interface for Lua.
    The interface is compatible with the standard Lua
    interpreter, i.e., the `lua` executable provided in a
    default Lua installation.

category:             Foreign
abi:                  d30024c6498bde2ce338746e13ccccbe
exposed:              True
exposed-modules:      HsLua.CLI
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-cli-1.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hslua-cli
hs-libraries:         HShslua-cli-1.4.2-2DWYwhXGNSHoe6K9HpV3l
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-Fc3hUeMzwrzD2zPByqV3Tq
    hslua-marshalling-2.3.1-3lwUpI0L8lcFUiaobcEJOA
    hslua-repl-0.1.2-GqggsgoN4bD4GKqvsPRvJe
    lua-2.3.3-KskfZ23ZEZSApu5FUEoWMy text-2.0.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/hslua-cli/html/hslua-cli.haddock
haddock-html:         /usr/share/doc/hslua-cli/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
